#include <unistd.h>
#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <semaphore.h>
#include <pthread.h>
#include <fuse.h>

#include <tcutil.h>
#include <tchdb.h>
#include <tcbdb.h>
#include <stdlib.h>
#include <stdbool.h>

#include "lib_log.h"
#include "lib_safe.h"
#include "lib_cfg.h"
#include "lib_str.h"
#include "retcodes.h"
#ifdef LZO
#include "lib_lzo.h"
#else
#include "lib_qlz.h"
#endif
#include "lib_tc.h"

char *logname;
char *function;
int debug = 0;
struct configdata *config;

int BLKSIZE = 0;
int max_threads;

extern TCHDB *dbb;
extern TCHDB *dbu;
extern TCHDB *dbp;
extern TCBDB *dbl;
extern TCHDB *dbs;
extern TCHDB *dbdta;
extern TCBDB *dbdirent;

BLKDTA **tdta = NULL;

void usage(char *name)
{
    printf("Usage: %s /path_to_config.cfg\n", name);
    exit(-1);
}

int main(int argc, char *argv[])
{
    char *dbpath;
    char *dbg = NULL;

    struct stat stbuf;

    if (argc < 2)
        usage(argv[0]);

    dbg = getenv("DEBUG");
    if (NULL != dbg)
        debug = atoi(dbg);

    FUNC;
    if (-1 == r_env_cfg(argv[1]))
        usage(argv[0]);
    config = s_malloc(sizeof(struct configdata));
    config->blockdata = read_val("BLOCKDATA_PATH");
    config->blockdatabs = read_val("BLOCKDATA_BS");
    config->blockusage = read_val("BLOCKUSAGE_PATH");
    config->blockusage = read_val("BLOCKUSAGE_PATH");
    config->blockusagebs = read_val("BLOCKUSAGE_BS");
    config->dirent = read_val("DIRENT_PATH");
    config->direntbs = read_val("DIRENT_BS");
    config->fileblock = read_val("FILEBLOCK_PATH");
    config->fileblockbs = read_val("FILEBLOCK_BS");
    config->meta = read_val("META_PATH");
    config->metabs = read_val("META_BS");
    config->hardlink = read_val("HARDLINK_PATH");
    config->hardlinkbs = read_val("HARDLINK_BS");
    config->symlink = read_val("SYMLINK_PATH");
    config->symlinkbs = read_val("SYMLINK_BS");
    dbpath = as_sprintf("%s/blockdata.tch", config->blockdata);
    if (-1 != stat(dbpath, &stbuf)) {
        fprintf(stderr,
                "Data %s already exists, please remove it and try again\n",
                dbpath);
        exit(EXIT_DATAERR);
    }
    formatfs();
    sync();
    free(config);
    exit(0);
}
